@@ -199,7 +199,9 @@ test_dsa (Test *test, gconstpointer unused)
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	g_test_add ("/gcr/fingerprint/rsa", Test, NULL, setup, test_rsa, teardown);
